@@ -606,9 +606,7 @@ define([
 		_hostMenu: null,
 
 		_resize: function() {
-			if (_overviewVisible) {
-				this._updateMoreTabsVisibility();
-			}
+			this._updateTabsVisibility();
 		},
 
 		setupGui: function() {
@@ -629,8 +627,8 @@ define([
 
 			if (_overviewVisible) {
 				this.setupBackToOverview();
-				this._setupModuleTabs();
 			}
+			this._setupModuleTabs();
 
 			this.addChild(this._headerRight);
 			if (_overviewVisible) {
@@ -658,15 +656,6 @@ define([
 			var aspectHandlesMap = {};
 			this._tabController.on('addChild', lang.hitch(this, function(module) {
 				if (!module.isOverview) {
-					var closeButton = Button.simpleIconButtonNode('x', 'umcMobileTab__closeButton');
-					on(closeButton, 'click', lang.hitch(this, function(evt) {
-						evt.stopImmediatePropagation();
-						module.closeModule();
-						if (mobileTabsContainer.children.length === 0) {
-							this._mobileTabsButton.set('checked', false);
-						}
-					}));
-
 					var tab = put(`div.umcMobileTab#umcMobileTab_${module.id}`);
 					on(tab, 'click', lang.hitch(this, function(evt) {
 						evt.stopImmediatePropagation();
@@ -674,14 +663,24 @@ define([
 						this._mobileTabsButton.set('checked', false);
 					}));
 					var labelNode = put(tab, 'div.umcMobileTab__label', module.title);
-					put(tab, closeButton);
+					if (module.closable) {
+						var closeButton = Button.simpleIconButtonNode('x', 'umcMobileTab__closeButton');
+						on(closeButton, 'click', lang.hitch(this, function(evt) {
+							evt.stopImmediatePropagation();
+							module.closeModule();
+							if (mobileTabsContainer.children.length === 0 || !this._areTabsVisible()) {
+								this._mobileTabsButton.set('checked', false);
+							}
+						}));
+						put(tab, closeButton);
+					}
 					put(mobileTabsContainer, tab);
 
-					this._updateMoreTabsVisibility();
+					this._updateTabsVisibility();
 
 					aspectHandlesMap[module.id] = aspect.after(module, '_setTitleAttr', lang.hitch(this, function(label) {
 						labelNode.innerHTML = label;
-						this._updateMoreTabsVisibility();
+						this._updateTabsVisibility();
 					}), true);
 				}
 			}));
@@ -693,19 +692,35 @@ define([
 				if (node) {
 					node.remove();
 				}
-				this._updateMoreTabsVisibility();
+				this._updateTabsVisibility();
 			}));
 
 			this.addChild(this._tabController);
+			domClass.toggle(this._tabController.domNode, 'umcMainTabController--overviewless', !_overviewVisible);
 			this._headerStretch = put(this.domNode, 'div.umcHeaderStretch.dijitDisplayNone');
 		},
 
-		_updateMoreTabsVisibility: function() {
-			this._mobileTabsButton.counterNode.innerHTML = this._tabContainer.getChildren().length - 1; // -1 for hidden overview tab
+		_getNumOfTabs: function() {
+			return this._tabContainer.getChildren().filter(function(tab) {
+				return !tab.isOverview;
+			}).length;
+		},
+
+		_areTabsVisible: function() {
+			return _overviewVisible || this._getNumOfTabs() >= 2;
+		},
+
+		_updateTabsVisibility: function() {
+			var areTabsVisible = this._areTabsVisible();
+			// update mobile tabs
+			this._mobileTabsButton.counterNode.innerHTML = this._getNumOfTabs();
 			this.set('mobileTabsView', false);
-			window.requestAnimationFrame(lang.hitch(this, function() {
-				this.set('mobileTabsView', this._tabController.domNode.scrollWidth > this._tabController.domNode.clientWidth);
-			}));
+			if (areTabsVisible) {
+				window.requestAnimationFrame(lang.hitch(this, function() {
+					this.set('mobileTabsView', this._tabController.domNode.scrollWidth > this._tabController.domNode.clientWidth);
+				}));
+			}
+			tools.toggleVisibility(this._tabController, areTabsVisible);
 		},
 
 		setupSearchField: function() {
@@ -1494,7 +1509,7 @@ define([
 						this._updateQuery(category);
 
 						this._header._search._searchTextBox._updateInlineLabelVisibility();
-						this._header._updateMoreTabsVisibility();
+						this._header._updateTabsVisibility();
 					}),
 					categoryID: category.id
 				});
@@ -1620,10 +1635,15 @@ define([
 				}
 				if (!tab) {
 					// module is not open yet, open it
+
+					// if ther overview is disabled, the first opened module is not closable.
+					// Modules opened after that are closable
+					var closable = _overviewVisible || this._header._getNumOfTabs() >= 1;
+
 					var params = lang.mixin({
 						title: module.name,
 						//iconClass: tools.getIconClass(module.icon),
-						closable: _overviewVisible,  // closing tabs is only enabled if the overview is visible
+						closable: closable,
 						moduleFlavor: module.flavor,
 						moduleID: module.id,
 						categoryColor: module.category_for_color,
@@ -1641,6 +1661,7 @@ define([
 				}
 				this._tabContainer.selectChild(tab, true);
 				deferred.resolve(tab);
+
 			})).otherwise(function(err) {
 				console.warn('Error initializing module ' + module.id + ':', err);
 				tools.checkReloadRequired();
